@@ -1,23 +1,10 @@
-/***************************************************************************
- *   Copyright (C) 2009-2010 by Peter Penz <peter.penz@gmx.at>             *
- *   Copyright (C) 2011 Canonical Ltd.                                     *
- *        By Jonathan Riddell <jriddell@ubuntu.com>                        *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009-2010 Peter Penz <peter.penz@gmx.at>
+    SPDX-FileCopyrightText: 2011 Canonical Ltd.
+    SPDX-FileContributor: Jonathan Riddell <jriddell@ubuntu.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "fileviewbazaarplugin.h"
 
@@ -33,21 +20,20 @@
 #include <QStringList>
 #include <QTextStream>
 
-K_PLUGIN_FACTORY(FileViewBazaarPluginFactory, registerPlugin<FileViewBazaarPlugin>();)
-K_EXPORT_PLUGIN_VERSION(2)
+K_PLUGIN_CLASS_WITH_JSON(FileViewBazaarPlugin, "fileviewbazaarplugin.json")
 
 FileViewBazaarPlugin::FileViewBazaarPlugin(QObject* parent, const QList<QVariant>& args) :
     KVersionControlPlugin(parent),
     m_pendingOperation(false),
     m_versionInfoHash(),
-    m_updateAction(0),
-    m_pullAction(0),
-    m_pushAction(0),
-    m_showLocalChangesAction(0),
-    m_commitAction(0),
-    m_addAction(0),
-    m_removeAction(0),
-    m_logAction(0),
+    m_updateAction(nullptr),
+    m_pullAction(nullptr),
+    m_pushAction(nullptr),
+    m_showLocalChangesAction(nullptr),
+    m_commitAction(nullptr),
+    m_addAction(nullptr),
+    m_removeAction(nullptr),
+    m_logAction(nullptr),
     m_command(),
     m_arguments(),
     m_errorMsg(),
