@@ -1,23 +1,10 @@
-/******************************************************************************
- *   Copyright (C) 2010 by Peter Penz <peter.penz@gmx.at>                     *
- *   Copyright (C) 2010 by Sebastian Doerner <sebastian@sebastian-doerner.de> *
- *   Copyright (C) 2010 by Johannes Steffen <jsteffen@st.ovgu.de>             *
- *                                                                            *
- *   This program is free software; you can redistribute it and/or modify     *
- *   it under the terms of the GNU General Public License as published by     *
- *   the Free Software Foundation; either version 2 of the License, or        *
- *   (at your option) any later version.                                      *
- *                                                                            *
- *   This program is distributed in the hope that it will be useful,          *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of           *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
- *   GNU General Public License for more details.                             *
- *                                                                            *
- *   You should have received a copy of the GNU General Public License        *
- *   along with this program; if not, write to the                            *
- *   Free Software Foundation, Inc.,                                          *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA               *
- ******************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010 Peter Penz <peter.penz@gmx.at>
+    SPDX-FileCopyrightText: 2010 Sebastian Doerner <sebastian@sebastian-doerner.de>
+    SPDX-FileCopyrightText: 2010 Johannes Steffen <jsteffen@st.ovgu.de>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "fileviewgitplugin.h"
 #include "checkoutdialog.h"
@@ -39,19 +26,18 @@
 #include <QDir>
 #include <QTextBrowser>
 
-K_PLUGIN_FACTORY(FileViewGitPluginFactory, registerPlugin<FileViewGitPlugin>();)
-K_EXPORT_PLUGIN_VERSION(2);
+K_PLUGIN_CLASS_WITH_JSON(FileViewGitPlugin, "fileviewgitplugin.json")
 
 FileViewGitPlugin::FileViewGitPlugin(QObject* parent, const QList<QVariant>& args) :
     KVersionControlPlugin(parent),
     m_pendingOperation(false),
-    m_addAction(0),
-    m_removeAction(0),
-    m_checkoutAction(0),
-    m_commitAction(0),
-    m_tagAction(0),
-    m_pushAction(0),
-    m_pullAction(0)
+    m_addAction(nullptr),
+    m_removeAction(nullptr),
+    m_checkoutAction(nullptr),
+    m_commitAction(nullptr),
+    m_tagAction(nullptr),
+    m_pushAction(nullptr),
+    m_pullAction(nullptr)
 {
     Q_UNUSED(args);
 
@@ -142,7 +128,7 @@ QString FileViewGitPlugin::localRepositoryRoot(const QString& directory) const
 }
 
 int FileViewGitPlugin::readUntilZeroChar(QIODevice* device, char* buffer, const int maxChars) {
-    if (buffer == 0) { // discard until next \0
+    if (buffer == nullptr) { // discard until next \0
         char c;
         while (device->getChar(&c) && c != '\0')
             ;
@@ -218,7 +204,7 @@ bool FileViewGitPlugin::beginRetrieval(const QString& directory)
                 case 'R':
                     state = LocallyModifiedVersion;
                     // Renames list the old file name directly afterwards, separated by \0.
-                    readUntilZeroChar(&process, 0, 0); // discard old file name
+                    readUntilZeroChar(&process, nullptr, 0); // discard old file name
                     break;
             }
             // overwrite status depending on the working tree
