@@ -1,21 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2011 by Vishesh Yadav <vishesh3y@gmail.com>             *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2011 Vishesh Yadav <vishesh3y@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "hgwrapper.h"
 
@@ -28,7 +15,7 @@
 //FIXME: Add/Remove/Revert argument length limit. Divide the list.
 //FIXME: Cannot create thread for parent that is in different thread.
 
-HgWrapper *HgWrapper::m_instance = 0;
+HgWrapper *HgWrapper::m_instance = nullptr;
 
 HgWrapper::HgWrapper(QObject *parent) :
     QObject(parent)
@@ -63,7 +50,7 @@ HgWrapper *HgWrapper::instance()
 void HgWrapper::freeInstance()
 {
     delete m_instance;
-    m_instance = 0;
+    m_instance = nullptr;
 }
 
 void HgWrapper::slotOperationCompleted(int exitCode, 
@@ -149,7 +136,7 @@ QString HgWrapper::getCurrentDir() const
 void HgWrapper::updateBaseDir()
 {
     m_process.setWorkingDirectory(m_currentDir);
-    m_process.start(QLatin1String("hg root"));
+    m_process.start(QStringLiteral("hg"), QStringList{QStringLiteral("root")});
     m_process.waitForFinished();
     m_hgBaseDir = QString(m_process.readAllStandardOutput()).trimmed();
 }
@@ -305,7 +292,7 @@ QStringList HgWrapper::getTags()
         char buffer[1048];
         while (m_process.readLine(buffer, sizeof(buffer)) > 0) {
             result << QString(buffer).split(QRegExp("\\s+"),
-                                            QString::SkipEmptyParts).first();
+                                            Qt::SkipEmptyParts).first();
         }
     }
     return result;
