@@ -1,21 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2009-2011 by Peter Penz <peter.penz19@gmail.com>        *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009-2011 Peter Penz <peter.penz19@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "fileviewsvnplugin.h"
 
@@ -51,8 +38,7 @@
 
 #include "svncommands.h"
 
-K_PLUGIN_FACTORY(FileViewSvnPluginFactory, registerPlugin<FileViewSvnPlugin>();)
-K_EXPORT_PLUGIN_VERSION(2)
+K_PLUGIN_CLASS_WITH_JSON(FileViewSvnPlugin, "fileviewsvnplugin.json")
 
 FileViewSvnPlugin::FileViewSvnPlugin(QObject* parent, const QList<QVariant>& args) :
     KVersionControlPlugin(parent),
@@ -542,7 +528,7 @@ void FileViewSvnPlugin::slotOperationError()
 void FileViewSvnPlugin::slotShowUpdatesToggled(bool checked)
 {
     FileViewSvnPluginSettings* settings = FileViewSvnPluginSettings::self();
-    Q_ASSERT(settings != 0);
+    Q_ASSERT(settings != nullptr);
     settings->setShowUpdates(checked);
     settings->save();
 
